"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupAnalogGenerator = void 0;
const devkit_1 = require("@nx/devkit");
const node_path_1 = require("node:path");
const version_utils_1 = require("../../utils/version-utils");
const add_analog_dependencies_1 = require("./lib/add-analog-dependencies");
const update_test_tsconfig_1 = require("./lib/update-test-tsconfig");
const update_test_target_1 = require("./lib/update-test-target");
const update_build_target_1 = require("./lib/update-build-target");
const update_serve_target_1 = require("./lib/update-serve-target");
const update_package_json_1 = require("./lib/update-package-json");
const update_index_html_1 = require("./lib/update-index-html");
const update_main_1 = require("./lib/update-main");
const update_app_tsconfig_1 = require("./lib/update-app-tsconfig");
function addFiles(tree, options) {
    const isNx = tree.read('/nx.json');
    const projects = (0, devkit_1.getProjects)(tree);
    const projectConfig = projects.get(options.project);
    const templateOptions = {
        ...options,
        offsetFromRoot: isNx ? '../../' : './',
        projectRoot: projectConfig.root,
        template: '',
    };
    (0, devkit_1.generateFiles)(tree, (0, node_path_1.join)(__dirname, 'files'), projectConfig.root || '.', templateOptions);
    if (options.vitest) {
        (0, devkit_1.generateFiles)(tree, (0, node_path_1.join)(__dirname, 'test-files'), projectConfig.root || '.', templateOptions);
    }
}
async function setupAnalogGenerator(tree, options) {
    const angularVersion = (0, version_utils_1.getInstalledPackageVersion)(tree, '@angular/core');
    (0, add_analog_dependencies_1.addAnalogDependencies)(tree, angularVersion);
    (0, update_build_target_1.updateBuildTarget)(tree, options);
    (0, update_serve_target_1.updateServeTarget)(tree, options);
    if (options.vitest) {
        (0, update_test_target_1.updateTestTarget)(tree, options);
        (0, update_test_tsconfig_1.updateTestTsConfig)(tree, options);
    }
    (0, update_app_tsconfig_1.updateAppTsConfig)(tree, options);
    (0, update_package_json_1.updatePackageJson)(tree, options);
    (0, update_index_html_1.updateIndex)(tree, options);
    (0, update_main_1.updateMain)(tree, options);
    addFiles(tree, options);
    await (0, devkit_1.formatFiles)(tree);
    return () => {
        (0, devkit_1.installPackagesTask)(tree);
    };
}
exports.setupAnalogGenerator = setupAnalogGenerator;
exports.default = setupAnalogGenerator;
//# sourceMappingURL=generator.js.map