"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateBuildTarget = void 0;
const devkit_1 = require("@nx/devkit");
function updateBuildTarget(tree, schema) {
    const angularJsonPath = '/angular.json';
    const commonConfig = {
        options: {
            configFile: 'vite.config.ts',
            main: 'src/main.ts',
            outputPath: 'dist/client',
            tsConfig: 'tsconfig.app.json',
        },
        defaultConfiguration: 'production',
        configurations: {
            development: {
                mode: 'development',
            },
            production: {
                sourcemap: false,
                mode: 'production',
            },
        },
    };
    if (tree.exists(angularJsonPath)) {
        (0, devkit_1.updateJson)(tree, angularJsonPath, (json) => {
            json.projects[schema.project].root = '.';
            json.projects[schema.project].architect.build = {
                builder: '@analogjs/platform:vite',
                ...commonConfig,
            };
            return json;
        });
    }
    else {
        const projects = (0, devkit_1.getProjects)(tree);
        const projectConfig = projects.get(schema.project);
        projectConfig.targets.build = {
            executor: '@analogjs/platform:vite',
            ...commonConfig,
            options: {
                configFile: `${(0, devkit_1.joinPathFragments)(projectConfig.root, 'vite.config.ts')}`,
                main: `${(0, devkit_1.joinPathFragments)(projectConfig.root, 'src/main.ts')}`,
                outputPath: `dist/${(0, devkit_1.joinPathFragments)(projectConfig.root, 'client')}`,
                tsConfig: `${(0, devkit_1.joinPathFragments)(projectConfig.root, 'tsconfig.app.json')}`,
            },
        };
        (0, devkit_1.updateProjectConfiguration)(tree, schema.project, projectConfig);
    }
}
exports.updateBuildTarget = updateBuildTarget;
//# sourceMappingURL=update-build-target.js.map