"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateServeTarget = void 0;
const devkit_1 = require("@nx/devkit");
function updateServeTarget(tree, schema) {
    const angularJsonPath = '/angular.json';
    const commonConfig = {
        defaultConfiguration: 'development',
        options: {
            buildTarget: `${schema.project}:build`,
            port: 4200,
        },
        configurations: {
            development: {
                buildTarget: `${schema.project}:build:development`,
                hmr: true,
            },
            production: {
                buildTarget: `${schema.project}:build:production`,
            },
        },
    };
    if (tree.exists(angularJsonPath)) {
        (0, devkit_1.updateJson)(tree, angularJsonPath, (json) => {
            json.projects[schema.project].root = '.';
            json.projects[schema.project].architect.serve = {
                builder: '@analogjs/platform:vite-dev-server',
                ...commonConfig,
            };
            return json;
        }, { expectComments: true, allowTrailingComma: true });
    }
    else {
        const projects = (0, devkit_1.getProjects)(tree);
        const projectConfig = projects.get(schema.project);
        projectConfig.targets.serve = {
            executor: '@analogjs/platform:vite-dev-server',
            ...commonConfig,
        };
        (0, devkit_1.updateProjectConfiguration)(tree, schema.project, projectConfig);
    }
}
exports.updateServeTarget = updateServeTarget;
//# sourceMappingURL=update-serve-target.js.map