"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.analogPageGeneratorSchematic = exports.analogPageGenerator = void 0;
const devkit_1 = require("@nx/devkit");
const node_path_1 = require("node:path");
function normalizeOptions(tree, options) {
    const projectRoot = `${(0, devkit_1.getWorkspaceLayout)(tree).appsDir}/${options.project}`;
    return {
        ...options,
        projectRoot,
    };
}
function generateFileName(input) {
    const pattern = /^[a-zA-Z0-9]+\.\[[a-zA-Z0-9-]+\]$/;
    if (pattern.test(input)) {
        return input.replace(/\[[a-zA-Z0-9-]+\]/, (match) => {
            const wordId = match.slice(1, -1);
            const camelCaseWordId = wordId.replace(/-([a-zA-Z0-9])/g, (_, letter) => letter.toUpperCase());
            return `[${camelCaseWordId}]`;
        });
    }
    else {
        return input;
    }
}
function addFiles(tree, options) {
    const splitName = options.pathname.split('/');
    const routeName = splitName[splitName.length - 1];
    const fileName = generateFileName(routeName);
    const templateOptions = {
        ...options,
        ...(0, devkit_1.names)(routeName),
        name: (0, devkit_1.names)(routeName).fileName,
        offsetFromRoot: (0, devkit_1.offsetFromRoot)(options.projectRoot),
        template: '',
        fileName,
    };
    const pageFolders = options.pathname.split('/').slice(0, -1);
    const pageDir = (0, node_path_1.join)(options.projectRoot, 'src/app/pages', ...pageFolders);
    (0, devkit_1.generateFiles)(tree, (0, node_path_1.join)(__dirname, 'files'), pageDir, templateOptions);
}
async function analogPageGenerator(tree, options) {
    const normalizedOptions = normalizeOptions(tree, options);
    if (options.redirectPage && !options.redirectPath) {
        throw new Error((0, devkit_1.stripIndents) `A redirectPath is required when redirectPage is true.`);
    }
    addFiles(tree, normalizedOptions);
    await (0, devkit_1.formatFiles)(tree);
}
exports.analogPageGenerator = analogPageGenerator;
exports.analogPageGeneratorSchematic = (0, devkit_1.convertNxGenerator)(analogPageGenerator);
exports.default = analogPageGenerator;
//# sourceMappingURL=generator.js.map