"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAnalogDependencies = void 0;
const semver_1 = require("semver");
const versions_1 = require("./ng_16_X/versions");
const devkit_1 = require("@nx/devkit");
const versions_2 = require("./ng_17_X/versions");
const versions_3 = require("./ng_15_X/versions");
const versions_4 = require("./ng_18_X/versions");
const dependencyKeys = [
    '@analogjs/content',
    '@analogjs/router',
    '@nx/angular',
];
const getAnalogDependencies = (ngVersion) => {
    const escapedNgVersion = ngVersion.replace(/[~^]/, '');
    const dependencies = getDependencies(escapedNgVersion);
    return { ...dependencies };
};
exports.getAnalogDependencies = getAnalogDependencies;
const getDependencies = (escapedAngularVersion) => {
    // fail out for versions <15.2.0
    if ((0, semver_1.lt)(escapedAngularVersion, '15.0.0')) {
        throw new Error((0, devkit_1.stripIndents) `Angular v15.0.0 or newer is required.`);
    }
    // install 15.x deps for versions <16.0.0
    if ((0, semver_1.lt)(escapedAngularVersion, '16.0.0')) {
        return {
            '@analogjs/content': versions_3.V15_X_ANALOG_JS_CONTENT,
            '@analogjs/router': versions_3.V15_X_ANALOG_JS_ROUTER,
            '@nx/angular': versions_3.V15_X_NX_ANGULAR,
        };
    }
    // install 16.x deps for versions <17.0.0
    if ((0, semver_1.lt)(escapedAngularVersion, '17.0.0')) {
        return {
            '@analogjs/content': versions_1.V16_X_ANALOG_JS_CONTENT,
            '@analogjs/router': versions_1.V16_X_ANALOG_JS_ROUTER,
            '@nx/angular': versions_1.V16_X_NX_ANGULAR,
        };
    }
    // install 17.x deps for versions <18.0.0
    if ((0, semver_1.lt)(escapedAngularVersion, '18.0.0')) {
        return {
            '@analogjs/content': versions_2.V17_X_ANALOG_JS_CONTENT,
            '@analogjs/router': versions_2.V17_X_ANALOG_JS_ROUTER,
            '@nx/angular': versions_2.V17_X_NX_ANGULAR,
        };
    }
    // return latest 18.x deps for versions >18.0.0
    return {
        '@analogjs/content': versions_4.V18_X_ANALOG_JS_CONTENT,
        '@analogjs/router': versions_4.V18_X_ANALOG_JS_ROUTER,
        '@nx/angular': versions_4.V18_X_NX_ANGULAR,
    };
};
//# sourceMappingURL=dependencies.js.map