"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAnalogDevDependencies = void 0;
const semver_1 = require("semver");
const versions_1 = require("./ng_16_X/versions");
const devkit_1 = require("@nx/devkit");
const versions_2 = require("./ng_15_X/versions");
const versions_3 = require("./ng_18_X/versions");
const devDependencyKeys = [
    '@analogjs/platform',
    '@analogjs/vite-plugin-angular',
    'jsdom',
    'vite-tsconfig-paths',
    'vitest',
    '@nx/vite',
];
const getAnalogDevDependencies = (ngVersion) => {
    const escapedNgVersion = ngVersion.replace(/[~^]/, '');
    const devDependencies = getDevDependencies(escapedNgVersion);
    return { ...devDependencies };
};
exports.getAnalogDevDependencies = getAnalogDevDependencies;
const getDevDependencies = (escapedAngularVersion) => {
    // fail out for versions <15.2.0
    if ((0, semver_1.lt)(escapedAngularVersion, '15.0.0')) {
        throw new Error((0, devkit_1.stripIndents) `Angular v15.0.0 or newer is required.`);
    }
    // install 15.x deps for versions <15.0.0
    if ((0, semver_1.lt)(escapedAngularVersion, '16.0.0')) {
        return {
            '@analogjs/platform': versions_2.V15_X_ANALOG_JS_PLATFORM,
            '@analogjs/vite-plugin-angular': versions_2.V15_X_ANALOG_JS_VITE_PLUGIN_ANGULAR,
            '@nx/vite': versions_2.V15_X_NX_VITE,
            jsdom: versions_2.V15_X_JSDOM,
            'vite-tsconfig-paths': versions_2.V15_X_VITE_TSCONFIG_PATHS,
            vitest: versions_2.V15_X_VITEST,
        };
    }
    // install 16.x deps for versions <17.0.0
    if ((0, semver_1.lt)(escapedAngularVersion, '17.0.0')) {
        return {
            '@analogjs/platform': versions_1.V16_X_ANALOG_JS_PLATFORM,
            '@analogjs/vite-plugin-angular': versions_1.V16_X_ANALOG_JS_VITE_PLUGIN_ANGULAR,
            '@nx/vite': versions_1.V16_X_NX_VITE,
            jsdom: versions_1.V16_X_JSDOM,
            'vite-tsconfig-paths': versions_1.V16_X_VITE_TSCONFIG_PATHS,
            vitest: versions_1.V16_X_VITEST,
        };
    }
    // install 16.x deps for versions <18.0.0
    if ((0, semver_1.lt)(escapedAngularVersion, '18.0.0')) {
        return {
            '@analogjs/platform': versions_1.V16_X_ANALOG_JS_PLATFORM,
            '@analogjs/vite-plugin-angular': versions_1.V16_X_ANALOG_JS_VITE_PLUGIN_ANGULAR,
            '@nx/vite': versions_1.V16_X_NX_VITE,
            jsdom: versions_1.V16_X_JSDOM,
            'vite-tsconfig-paths': versions_1.V16_X_VITE_TSCONFIG_PATHS,
            vitest: versions_1.V16_X_VITEST,
        };
    }
    // return latest 18.x deps for versions >18.0.0
    return {
        '@analogjs/platform': versions_3.V18_X_ANALOG_JS_PLATFORM,
        '@analogjs/vite-plugin-angular': versions_3.V18_X_ANALOG_JS_VITE_PLUGIN_ANGULAR,
        '@nx/vite': versions_3.V18_X_NX_VITE,
        jsdom: versions_3.V18_X_JSDOM,
        'vite-tsconfig-paths': versions_3.V18_X_VITE_TSCONFIG_PATHS,
        vitest: versions_3.V18_X_VITEST,
    };
};
//# sourceMappingURL=dev-dependencies.js.map